@@ -51,11 +51,11 @@
 
 struct CajaInformationPanelDetails
 {
-    GtkVBox *container;
+    GtkWidget *container;
     CajaWindowInfo *window;
     CajaSidebarTitle *title;
-    GtkHBox *button_box_centerer;
-    GtkVBox *button_box;
+    GtkWidget *button_box_centerer;
+    GtkWidget *button_box;
     gboolean has_buttons;
     CajaFile *file;
     guint file_changed_connection;
@@ -226,15 +226,20 @@ caja_information_panel_class_init (CajaInformationPanelClass *klass)
 static void
 make_button_box (CajaInformationPanel *information_panel)
 {
-    information_panel->details->button_box_centerer = GTK_HBOX (gtk_hbox_new (FALSE, 0));
-    gtk_box_pack_start (GTK_BOX (information_panel->details->container),
-                        GTK_WIDGET (information_panel->details->button_box_centerer), TRUE, TRUE, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+    information_panel->details->button_box_centerer = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    information_panel->details->button_box_centerer = gtk_hbox_new (FALSE, 0);
+#endif
 
-    information_panel->details->button_box = GTK_VBOX (caja_keep_last_vertical_box_new (4));
+    gtk_box_pack_start (GTK_BOX (information_panel->details->container),
+                        information_panel->details->button_box_centerer, TRUE, TRUE, 0);
+
+    information_panel->details->button_box = caja_keep_last_vertical_box_new (4);
     gtk_container_set_border_width (GTK_CONTAINER (information_panel->details->button_box), 8);
-    gtk_widget_show (GTK_WIDGET (information_panel->details->button_box));
+    gtk_widget_show (information_panel->details->button_box);
     gtk_box_pack_start (GTK_BOX (information_panel->details->button_box_centerer),
-                        GTK_WIDGET (information_panel->details->button_box),
+                        information_panel->details->button_box,
                         TRUE, TRUE, 0);
     information_panel->details->has_buttons = FALSE;
 }
@@ -255,11 +260,15 @@ caja_information_panel_init (CajaInformationPanel *information_panel)
     gtk_widget_add_events (GTK_WIDGET (information_panel), GDK_POINTER_MOTION_MASK);
 
     /* create the container box */
-    information_panel->details->container = GTK_VBOX (gtk_vbox_new (FALSE, 0));
+#if GTK_CHECK_VERSION (3, 0, 0)
+    information_panel->details->container = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
+    information_panel->details->container = gtk_vbox_new (FALSE, 0);
+#endif
     gtk_container_set_border_width (GTK_CONTAINER (information_panel->details->container), 0);
-    gtk_widget_show (GTK_WIDGET (information_panel->details->container));
+    gtk_widget_show (information_panel->details->container);
     gtk_container_add (GTK_CONTAINER (information_panel),
-                       GTK_WIDGET (information_panel->details->container));
+                       information_panel->details->container);
 
     /* allocate and install the index title widget */
     information_panel->details->title = CAJA_SIDEBAR_TITLE (caja_sidebar_title_new ());
@@ -998,7 +1007,7 @@ caja_information_panel_update_buttons (CajaInformationPanel *information_panel)
     if (information_panel->details->has_buttons)
     {
         gtk_container_remove (GTK_CONTAINER (information_panel->details->container),
-                              GTK_WIDGET (information_panel->details->button_box_centerer));
+                              information_panel->details->button_box_centerer);
         make_button_box (information_panel);
     }
 
@@ -1022,7 +1031,7 @@ caja_information_panel_update_buttons (CajaInformationPanel *information_panel)
         g_object_unref (default_app);
     }
 
-    gtk_widget_show (GTK_WIDGET (information_panel->details->button_box_centerer));
+    gtk_widget_show (information_panel->details->button_box_centerer);
 }
 
 static void
