@@ -246,7 +246,7 @@ location_button_create (CajaNavigationWindowPane *pane)
     GtkWidget *image;
     GtkWidget *button;
 
-    image = gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU);
+    image = gtk_image_new_from_icon_name ("gtk-edit", GTK_ICON_SIZE_MENU);
     gtk_widget_show (image);
 
     button = g_object_new (GTK_TYPE_TOGGLE_BUTTON,
@@ -537,6 +537,17 @@ notebook_button_press_cb (GtkWidget *widget,
         notebook_popup_menu_show (pane, event);
         return TRUE;
     }
+    else if (GDK_BUTTON_PRESS == event->type && 2 == event->button)
+    {
+        CajaWindowPane *wpane;
+        CajaWindowSlot *slot;
+
+        wpane = CAJA_WINDOW_PANE (pane);
+        slot = wpane->active_slot;
+        caja_window_slot_close (slot);
+
+        return FALSE;
+    }
 
     return FALSE;
 }
