@@ -110,7 +110,11 @@ static GType caja_zoom_control_accessible_get_type (void);
 
 #define NUM_ACTIONS ((int)G_N_ELEMENTS (caja_zoom_control_accessible_action_names))
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+G_DEFINE_TYPE (CajaZoomControl, caja_zoom_control, GTK_TYPE_BOX);
+#else
 G_DEFINE_TYPE (CajaZoomControl, caja_zoom_control, GTK_TYPE_HBOX);
+#endif
 
 static void
 caja_zoom_control_finalize (GObject *object)
@@ -312,7 +316,7 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
                     GINT_TO_POINTER (i));
     }
 
-    image = gtk_image_new_from_stock (GTK_STOCK_ZOOM_OUT, GTK_ICON_SIZE_MENU);
+    image = gtk_image_new_from_icon_name ("zoom-out", GTK_ICON_SIZE_MENU);
     zoom_control->details->zoom_out = gtk_button_new ();
     gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_out), FALSE);
     gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_out),
@@ -322,6 +326,9 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
     g_signal_connect (G_OBJECT (zoom_control->details->zoom_out),
                       "clicked", G_CALLBACK (zoom_out_clicked),
                       zoom_control);
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_orientable_set_orientation (GTK_ORIENTABLE (zoom_control), GTK_ORIENTATION_HORIZONTAL);
+#endif
     gtk_container_add (GTK_CONTAINER (zoom_control->details->zoom_out), image);
     gtk_box_pack_start (GTK_BOX (zoom_control),
                         zoom_control->details->zoom_out, FALSE, FALSE, 0);
@@ -363,7 +370,7 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
     gtk_box_pack_start (GTK_BOX (zoom_control),
                         zoom_control->details->zoom_button, TRUE, TRUE, 0);
 
-    image = gtk_image_new_from_stock (GTK_STOCK_ZOOM_IN, GTK_ICON_SIZE_MENU);
+    image = gtk_image_new_from_icon_name ("zoom-in", GTK_ICON_SIZE_MENU);
     zoom_control->details->zoom_in = gtk_button_new ();
     gtk_button_set_focus_on_click (GTK_BUTTON (zoom_control->details->zoom_in), FALSE);
     gtk_button_set_relief (GTK_BUTTON (zoom_control->details->zoom_in),
@@ -978,7 +985,11 @@ caja_zoom_control_accessible_get_type (void)
 
         type = eel_accessibility_create_derived_type
                ("CajaZoomControlAccessible",
+#if GTK_CHECK_VERSION (3, 0, 0)
+                GTK_TYPE_BOX,
+#else
                 GTK_TYPE_HBOX,
+#endif
                 caja_zoom_control_accessible_class_init);
 
         g_type_add_interface_static (type, ATK_TYPE_ACTION,
